function printMLtext(x,y,str,color,maxlen,vspacing,maxlines)
	-- DESCRIPTION
	-- Divides strings to allow for easy multiline printing.  Designed to be similar in syntax
	-- to the screen:print command, and actually can be used as a replacement for the 
	-- command entirely.  Note that this has been tested for the default font and default 
	-- text size only, although it should work with any mono-spaced font and text size.  
	-- LMelior 7/18/2006
	--
	-- INPUTS
	-- "x" and "y" - the horizontal and vertical pixel location of the first character.
	-- "str" - the input string
	-- "color" - defines the color of the text, as in the screen:print command
	-- "maxlen" (optional, but you probably want to set this) - maximum number of 
	-- -- characters you want to allow on one line.  
	-- -- -- The default value is 60 (it is the maximum number of characters that will fit on the 
	-- -- -- -- PSP screen when using the PSP's default font).
	-- "vspacing" (optional) - vertical spacing, in pixels,  between consecutive lines of text
	-- -- The default value is 15 pixels.
	-- "maxlines" (optional) - allows you to define the maximum number of lines of text that
	-- -- you want to display, and it will wait for player input to continue to the next line.  If 
	-- -- -- the input string exceeds these parameters, it will only print the first screen, but it 
	-- -- -- -- will return the remainder of the string, so you can easily run it through again 
	-- -- -- -- -- (see Example 2).
	-- -- -- -- -- -- The default value is 18 lines, because along with the other defaults, this 
	-- -- -- -- -- -- -- will fill up the entire PSP screen with text.   
	-- Note: if you want to define "vspacing" or "maxlines," you must define the
	-- -- parameter(s) before it!
	--
	-- EXAMPLES
	-- Example 1: 
	-- -- stra="This string is too long to fit on one line if the "
	-- -- strb="maximum length of the line is 30 characters."
	-- -- printMLtext(230, 10, stra .. strb, Color.new(255,255,255), 30)
	--
	-- Example 2:
	-- str=(very long string)
	-- while true do
	--	screen:clear()
	--	pad=Controls.read()
	--	remainder=printMLtext(230, 10, str, Color.new(255,255,255), 30, 15, 10)
	--	if pad:cross() and remainder~=nil then
	--		screen.waitVblankStart(8)
	--	 	str=remainder
	--	end
	--	screen.waitVblankStart()
	--	screen.flip()
	-- end

	-- Check for optional input
	if maxlen==nil then
		maxlen=60
	end
	if vspacing==nil then
		vspacing=15
	end
	if maxlines==nil then
		maxlines=18
	end
	
	-- Initialize remainder (will be overwritten if remainder exists)
	local remainder=nil
	
	if string.len(str)<=maxlen then	-- you didn't need to use this!
		screen:print(x,y,str,color)
	else
		local laststr=str	-- initialize variable to hold reduced string
		local strk=0		-- loop counter
		local substr={}		-- initialize substring table
		
		while string.len(laststr)>maxlen do
			strk=strk+1
			
			-- Chop off string at the max length plus one and reverse it (if there's a space at maxlen+1 it's OK!)
			-- -- This doesn't work on Luaplayer 0.14 for Windows, but it probably works in Luaplayer 0.20:
			-- local revstr=string.reverse(string.sub(laststr,1,maxlen))
			
			-- -- This works on Luaplayer 0.14 for windows:
			local tmp=string.sub(laststr,1,maxlen+1) -- chops off string at maxlen+1
			local revstr=""	-- initialize revstr and then build it
			
			for k=1,string.len(tmp) do
				revstr=revstr .. string.sub(tmp,-k,-k)
			end
			
			tmp=maxlen+1-string.find(revstr," ") -- find the index of last space
			
			-- use index to define the substring
			substr[strk]=string.sub(laststr,1,tmp)
			
			-- chop off the first substring to get ready for next loop
			laststr=string.sub(laststr,tmp+2)
		end
		
		-- add the last part of the string to the table (loop terminates before this step)
		strk=strk+1
		substr[strk]=laststr

		-- check of number of lines will fit on the screen in one printing (remainder = nil)
		if strk<=maxlines then
		
			for k=1,strk do
				screen:print(x,y+(k-1)*vspacing,substr[k],color)
			end
			
		else	-- print first screen and then build up remainder string from the unused substrings
		
			for k=1,maxlines do
				screen:print(x,y+(k-1)*vspacing,substr[k],color)
			end
			
			remainder=substr[maxlines+1]
			
			for k=2,strk-maxlines do
				remainder=remainder .. " " .. substr[maxlines+k]
			end
		end
	return remainder
	end
end

function OptionsMenu()

	-- print menu
	screen:blit(0,0,title)
	screen:blit(selector.x,115+selector.yind*20,selector.image)
	screen:print(200,140,"BGM Level",white)
	screen:print(200,160,"SFX Level",white)
	screen:print(200,180,"Game Info",white)
	screen:print(200,200,"Back",white)
	local offset=string.len(BGMLevel)
	screen:print(350-offset*8,140,BGMLevel,white)
	local offset=string.len(SFXLevel)
	screen:print(350-offset*8,160,SFXLevel,white)
	screen:blit(300,147,buttons,0,15,15,15)
	screen:blit(361,147,buttons,30,15,15,15)
	
	if pad:up() and oldpad:up()~=pad:up() then
		selector.yind=selector.yind-1
		cursor:play()
	end

	if pad:down() and oldpad:down()~=pad:down() then
		selector.yind=selector.yind+1
		cursor:play()
	end

	if selector.yind>4 then
		selector.yind=1
	elseif selector.yind<1 then
		selector.yind=4
	end

	if pad:left() then
		if selector.yind==1 and BGMLevel>0 then
			BGMLevel=BGMLevel-1
		elseif selector.yind==2 and SFXLevel>0 then
			SFXLevel=SFXLevel-1
		end
	end
	if pad:right() then
		if selector.yind==1 and BGMLevel<128 then
			BGMLevel=BGMLevel+1
		elseif selector.yind==2 and SFXLevel<128 then
			SFXLevel=SFXLevel+1
		end
	end
	if pad:cross() and oldpad:cross()~=pad:cross() then
		if selector.yind==3 then
		local showhow=true
		local str="You are being attacked by zombies!  There are a few things you should know about zombies that will aid in your survival.  First, even though they prefer human brains, they eat everything...including each other.  Zombies don't have regular blood though, they have deadly acid filling what is left of their blood vessels.  So, when they eat each other, the result is a bubbling pool of acid.  Second, they come after you as straight as possible, no matter what is in their way.  They don't hesitate to walk into fire or pools of acid, even though it turns them into pools of acid when they do it.  Hey, zombies don't think, you know, unless by 'think' you mean 'try as hard as they can to eat human brains.'  Lastly, you do have one extra means of escape that the zombies can't use: teleportation.  It takes quite a bit of energy to teleport to a safe location, however, so you can only do so five times before you have to recharge.  You can, however, teleport completely at random as many times as you want.  For obvious reasons, this isn't always the smartest thing to do.  Well, good luck!"
			while true do
				screen:clear()
				screen.waitVblankStart(10)
				pad=Controls.read()
				screen:blit(0,0,title)
				remainder=printMLtext(120, 80, str, white, 36, 12, 14)
				if pad:cross() and oldpad:cross()~=pad:cross() and remainder~=nil then
					str=remainder
				end
				if pad:cross() and oldpad:cross()~=pad:cross() and remainder==nil then
					break
				end
				screen.waitVblankStart()
				screen.flip()
				oldpad=pad
			end
		end
		if selector.yind==4 then
			gameState=backState
			selector.yind=1
		end
	end
	Music.volume(BGMLevel)
	SoundSystem.SFXVolume(SFXLevel)
end
	

function MainMenu()
	if not Music.playing() then
		Music.playFile("zbgmusic.it")
	end
	-- if not bgmusic:playing() then
		-- bgmusic:play()
	-- end
	-- check high score
	file=io.open("hs.txt","r")
	highscore=file:read("*n")
	file:close()

	--print menu
	screen:blit(0,0,title)
	screen:blit(selector.x+(selector.yind-1)*11,115+selector.yind*20,selector.image)
	screen:print(200,140,"Start Game",white)
	screen:print(211,160,"Options",white)
	screen:print(222,180,"Exit",white)
	screen:print(200,240,"High Score: " .. highscore,red)

	if pad:up() and oldpad:up()~=pad:up() then
		selector.yind=selector.yind-1
		cursor:play()
	end

	if pad:down() and oldpad:down()~=pad:down() then
		selector.yind=selector.yind+1
		cursor:play()
	end

	if selector.yind>3 then
		selector.yind=1
	elseif selector.yind<1 then
		selector.yind=3
	end

	if pad:cross() and oldpad:cross()~=pad:cross() then
		if selector.yind==1 then
			gameState="gameinit"
			backState="game"
		elseif selector.yind==2 then
			gameState="options"
		elseif selector.yind==3 then
			if Music.playing() then
				Music.stop()
			end
			-- if bgmusic:playing() then
				-- bgmusic:stop()
			-- end
			running=false
		end
	end
end
