function genzMap(level)
	
	-- map size for zombie game
	xsize=32
	ysize=21
	
	-- create a map of zeros
	mapmat = {}       -- initialize the map matrix
    for i=1,ysize do
      mapmat[i] = {}     	-- create a new row
      for j=1,xsize do
        mapmat[i][j] = 0
      end
    end
	
	-- add random obstacles to map (number depends on level)
	local ngoodobjs=math.floor(20/level)	--includes fires and other items not yet in game
	--local nbadobjs=math.floor(level/2)					--includes items not yet in game :)
	local nobjs=ngoodobjs	--+nbadobjs
	
	-- place obstacles on blank map (making sure random location is blank)
	local k=0
	while k<=nobjs do
		local tmp=3
		local tmpy=math.floor(math.random(1,ysize+1-.00001))
		local tmpx=math.floor(math.random(1,xsize+1-.00001))
		if mapmat[tmpy][tmpx]==0 then
			mapmat[tmpy][tmpx]=tmp
			k=k+1
		end
	end
end


function genZombies(level)
	nrzoms=6*level+4
	local k=1
	zombie={}
	while k<=nrzoms do
		local tmpy=math.random(ysize)
		local tmpx=math.random(xsize)
		if mapmat[tmpy][tmpx]==0 then
			zombie[k]={x=tmpx,y=tmpy,move=1,anim=math.random(20),dead=false}
			k=k+1
		end
	end
end


function placePlayer()
	local placed=false
	while not placed do
		local tmpy=math.random(ysize)
		local tmpx=math.random(xsize)
		if mapmat[tmpy][tmpx]==0 then
			player={x=tmpx,y=tmpy,move=1,anim=math.random(1,20)}
			placed=true
			for k=1,nrzoms do
				if player.x==zombie[k].x and player.y==zombie[k].y then
					placed=false
				end
			end
		end
	end
end


function GameInit(level)
	if Music.playing() then
		Music.stop()
	end
	-- if bgmusic:playing() then
		-- bgmusic:stop()
	-- end
	safenum=5
	mapmat=nil
	zombie=nil
	player=nil
	genzMap(level)
	genZombies(level)
	placePlayer()
	gameState="game"
end


function blitall()

	-- create prescreen
	local prescreen=Image.createEmpty(480,272)

	-- background
	prescreen:blit(0,0,background)
	
	-- map
	for i=1,ysize do
		for j=1,xsize do
			if mapmat[i][j]==3 or mapmat[i][j]==4 then
				prescreen:blit((j-1)*12+11, (i-1)*12+10, tiles, 12*mapmat[i][j], 12*math.ceil(2*animk/maxanimk)-12, 12, 12)
			end
		end
	end

	-- zombies
	for k=1,nrzoms do
		prescreen:blit((zombie[k].x-1)*12+11,(zombie[k].y-1)*12+10,tiles,12,12*math.ceil(2*zombie[k].anim/maxanimk)-12,12,12)
		zombie[k].anim=zombie[k].anim+1
		if zombie[k].anim>maxanimk then
			zombie[k].anim=1
		end
	end

	-- player
	prescreen:blit((player.x-1)*12+11,(player.y-1)*12+10,tiles,0,12*math.ceil(2*player.anim/maxanimk)-12,12,12)
	player.anim=player.anim+1
	if player.anim>maxanimk then
		player.anim=1
	end

	-- level
	local offset=string.len(level)
	prescreen:print(440-offset*4,40,level,white)
	
	-- score
	local offset=string.len(score)
	prescreen:print(440-offset*4,80,score,white)
	
	-- number of zombies left
	local offset=string.len(nrzoms)
	prescreen:print(440-offset*4,130,nrzoms,white)
	
	-- number of safe teleports left
	local offset=string.len(safenum)
	prescreen:print(440-offset*4,210,safenum,white)
	
	-- blit prescreen to screen
	screen:blit(0,0,prescreen)
end


function closestZom(xpos,ypos)
	local closest=100
	for k=1,nrzoms do
		if math.abs(zombie[k].x-xpos)>math.abs(zombie[k].y-ypos) then
			if math.abs(zombie[k].x-xpos)<closest then
				closest=math.abs(zombie[k].x-xpos)
			end
		else
			if math.abs(zombie[k].y-ypos)<closest then
				closest=math.abs(zombie[k].y-ypos)
			end
		end
	end
	return closest
end


function teleportPlayer(safe)
	local telek=0
	if safe then
		-- generate random position and check surroundings
		local safetele=false
		while safetele==false do
			local tmpy=math.random(2,ysize-1)
			local tmpx=math.random(2,xsize-1)
			if closestZom(tmpx,tmpy)>1 and mapmat[tmpy][tmpx]==0 then 
				player.x=tmpx
				player.y=tmpy
				score=score-25
				safetele=true
			end
			telek=telek+1
			if telek>5000 then
				safe=false
				break
			end
		end
	else
		-- generate random position and go! (no penalty)
		local tmpy=math.random(ysize)
		local tmpx=math.random(xsize)
		player.x=tmpx
		player.y=tmpy
	end
end


function checkMove()
	local eaten=false
	local burned=false
	local boiled=false
	for k=1,nrzoms do
		if player.x==zombie[k].x and player.y==zombie[k].y then
			eaten=true
			chomp:play()
		end
	end
	if mapmat[player.y][player.x]==3 then
		burned=true
		burn:play()
	end
	if mapmat[player.y][player.x]==4 then
		boiled=true
		boil:play()
	end
	if burned or eaten or boiled then
		-- you lose!
		--screen:print(100,140,"You failed to escape the zombies...",white)
		screen:blit(11,10,lose)
		-- Music.stop()
		-- bgmusic:stop()
		if score>highscore then
			file=io.open("hs.txt","w")
			file:write(score)
			file:close()
			screen:print(100,200,"But you got the high score!",white)
		end
		die:play()
		screen:flip()
		screen.waitVblankStart(120)
		gameState="menu"
		backState="menu"
		level=1
		score=0
	else
		score=score+10
	end
end


function checkWin()
	if nrzoms==0 then
		score=score+100
		-- Music.stop()
		-- bgmusic:stop()
		while true do
			--screen:clear()
			pad=Controls.read()
			--screen:print(100,150,"All the zombies died! ...Again!",black)
			blitall()
			screen:blit(11,100,win)
			screen:flip()
			if pad:cross() and oldpad:cross()~=pad:cross() then 
				gameState="gameinit"
				level=level+1
				break
			end
			oldpad=pad
		end
	end
end


function checkZoms()
	-- check to see if they came in contact with another zombie
	for k1=1,nrzoms do
		for k2=1,nrzoms do
			if k2>k1 then
				if zombie[k1].x==zombie[k2].x and zombie[k1].y==zombie[k2].y then
					-- they eat each other!
					zombie[k1].dead=true
					zombie[k2].dead=true
				end
			end
		end
	end
	-- check to see if they were burned by fire or consumed by acid
	for k=1,nrzoms do
		if mapmat[zombie[k].y][zombie[k].x]==3 or mapmat[zombie[k].y][zombie[k].x]==4 then
			zombie[k].dead=true
		end
	end
	-- reduce the dead zombies to pools of acid
	for k=nrzoms,1,-1 do
		if zombie[k].dead then
			mapmat[zombie[k].y][zombie[k].x]=4
			table.remove(zombie,k)
			nrzoms=nrzoms-1
		end
	end	
end


function Zombie()
	-- if not Music.playing() then
		-- Music.playFile("zbgmusic.it")
	-- end
	-- if not bgmusic:playing() then
		-- bgmusic:play()
	-- end
	if gameState=="game" then
		blitall()
		checkWin()
		
		-- player movement
		while player.move==1 do
			screen:clear()
			blitall()
			pad=Controls.read()
			-- go up
			if pad:analogY()<-64 and math.abs(pad:analogX())<64 and player.y>1 then
				screen:blit((player.x-1)*12+11,(player.y-1)*12-2,tiles,0,24,12,12)
				if pad:cross() and oldpad:cross()~=pad:cross() then
					player.y=player.y-1
					player.move=player.move-1
				end
			-- go down
			elseif pad:analogY()>64 and math.abs(pad:analogX())<64 and player.y<ysize then
				screen:blit((player.x-1)*12+11,(player.y-1)*12+22,tiles,24,24,12,12)
				if pad:cross() and oldpad:cross()~=pad:cross() then
					player.y=player.y+1
					player.move=player.move-1
				end
			-- go left
			elseif pad:analogX()<-64 and math.abs(pad:analogY())<64 and player.x>1 then
				screen:blit((player.x-1)*12-1,(player.y-1)*12+10,tiles,36,24,12,12)
				if pad:cross() and oldpad:cross()~=pad:cross() then
					player.x=player.x-1
					player.move=player.move-1
				end
			-- go right
			elseif pad:analogX()>64 and math.abs(pad:analogY())<64 and player.x<xsize then
				screen:blit((player.x-1)*12+23,(player.y-1)*12+10,tiles,12,24,12,12)
				if pad:cross() and oldpad:cross()~=pad:cross() then
					player.x=player.x+1
					player.move=player.move-1
				end
			-- go up and right
			elseif pad:analogY()<-64 and pad:analogX()>64 and player.y>1 and player.x<xsize then
				screen:blit((player.x-1)*12+23,(player.y-1)*12-2,tiles,0,36,12,12)
				if pad:cross() and oldpad:cross()~=pad:cross() then
					player.x=player.x+1
					player.y=player.y-1
					player.move=player.move-1
				end
			-- go right and down
			elseif pad:analogY()>64 and pad:analogX()>64 and player.y<ysize and player.x<xsize then
				screen:blit((player.x-1)*12+23,(player.y-1)*12+22,tiles,12,36,12,12)
				if pad:cross() and oldpad:cross()~=pad:cross() then
					player.x=player.x+1
					player.y=player.y+1
					player.move=player.move-1
				end
			-- go down and left
			elseif pad:analogX()<-64 and pad:analogY()>64 and player.x>1 and player.y<ysize then
				screen:blit((player.x-1)*12-1,(player.y-1)*12+22,tiles,24,36,12,12)
				if pad:cross() and oldpad:cross()~=pad:cross() then
					player.x=player.x-1
					player.y=player.y+1
					player.move=player.move-1
				end
			-- go left and up
			elseif pad:analogX()<-64 and pad:analogY()<-64 and player.x>1 and player.y>1 then
				screen:blit((player.x-1)*12-1,(player.y-1)*12-2,tiles,36,36,12,12)
				if pad:cross() and oldpad:cross()~=pad:cross() then
					player.x=player.x-1
					player.y=player.y-1
					player.move=player.move-1
				end
			-- stay still
			else
				screen:blit((player.x-1)*12+11,(player.y-1)*12+10,tiles,48,24,12,12)
				if pad:cross() and oldpad:cross()~=pad:cross() then
					player.move=player.move-1
				end
			end
			-- teleport randomly
			if pad:triangle() and oldpad:triangle()~=pad:triangle() then
				teleportPlayer(false)
				player.move=player.move-1
			-- teleport to a safe location
			elseif pad:circle() and oldpad:circle()~=pad:circle() and safenum>0 then
				safenum=safenum-1
				teleportPlayer(true)
				player.move=player.move-1
			elseif pad:start() then
				gameState="options"
				break
			end
			screen.waitVblankStart()
			screen:flip()
			oldpad=pad
			animk=animk+1
			if animk>maxanimk then
				animk=1
			end
		end

	end
	
	if gameState=="game" then
		--checkMove()
		
		-- zombie movement
		for k=1,nrzoms do
			-- move up
			if player.x==zombie[k].x and player.y<zombie[k].y then
				zombie[k].y=zombie[k].y-1
				--zombie[k].move=zombie[k].move-1
			-- move down
			elseif player.x==zombie[k].x and player.y>zombie[k].y then
				zombie[k].y=zombie[k].y+1
				--zombie[k].move=zombie[k].move-1
			-- move left
			elseif player.x<zombie[k].x and player.y==zombie[k].y then
				zombie[k].x=zombie[k].x-1
				--zombie[k].move=zombie[k].move-1
			-- move right
			elseif player.x>zombie[k].x and player.y==zombie[k].y then
				zombie[k].x=zombie[k].x+1
				--zombie[k].move=zombie[k].move-1
			-- move up and right
			elseif player.x>zombie[k].x and player.y<zombie[k].y then
				zombie[k].x=zombie[k].x+1
				zombie[k].y=zombie[k].y-1
				--zombie[k].move=zombie[k].move-1
			-- move right and down
			elseif player.x>zombie[k].x and player.y>zombie[k].y then
				zombie[k].x=zombie[k].x+1
				zombie[k].y=zombie[k].y+1
				--zombie[k].move=zombie[k].move-1
			-- move down and left
			elseif player.x<zombie[k].x and player.y>zombie[k].y then
				zombie[k].x=zombie[k].x-1
				zombie[k].y=zombie[k].y+1
				--zombie[k].move=zombie[k].move-1
			-- move left and up
			elseif player.x<zombie[k].x and player.y<zombie[k].y then
				zombie[k].x=zombie[k].x-1
				zombie[k].y=zombie[k].y-1
				--zombie[k].move=zombie[k].move-1
			end
		end

		checkMove()
		checkZoms()
		player.move=player.move+1
		animk=animk+1
		if animk>maxanimk then
			animk=1
		end
	end
end
